This directory contains the template files that are processed by `cmake-init`
and written to disk. These files are licensed using the [Unlicense][1] license,
which allows them both in unprocessed and processed form to be used by anyone
for whatever purpose they wish. See the [license](LICENSE) for more details.

[1]: https://unlicense.org/
